Macro wproc_macro::span_of [−][src]
macro_rules! span_of {
($src : expr) => { ... };
}Expand description
Returns a Span covering the complete contents of this syntax tree node, or Span::call_site() if this node is empty.
macro_rules! span_of {
($src : expr) => { ... };
}Returns a Span covering the complete contents of this syntax tree node, or Span::call_site() if this node is empty.