Crate wproc_macro[−][src]
Tools for writing procedural macroses.
Macros
Returns a Span covering the complete contents of this syntax tree node, or Span::call_site() if this node is empty.
Macro for diagnostics purpose to export both syntax tree and source code behind it into string.
Macro for diagnostics purpose to print both syntax tree and source code behind it.
Enums
Kind of container.
Traits
A trait that can provide the Span of the complete contents of a syntax
tree node.
Trait to implement method span() for those structures which module::syn do not have it implemented.
Functions
Returns a Span covering the complete contents of this syntax tree node, or Span::call_site() if this node is empty.
Return kind of container specified by type.
Return the specified number of parameters of the type.
Check is the rightmost item of path refering a type is specified type.