Crate wproc_macro[][src]

Tools for writing procedural macroses.

Macros

Macro for diagnostics purpose to export both syntax tree and source code behind it into string.

Macro for diagnostics purpose to print both syntax tree and source code behind it.

Enums

Kind of container.

Traits

A trait that can provide the Span of the complete contents of a syntax tree node.

Trait to implement method span() for those structures which do not have it implemented.

Functions

Return kind of container specified by type. Good to verify alloc::vec::Vec< i32 > is vector. Good to verify std::collections::HashMap< i32, i32 > is hash map.

Return the specified number of parameters of the type. Good to getting i32 from core::option::Option< i32 > or alloc::vec::Vec< i32 >

Check is the rightmost item of path refering a type is specified type. Good to verify core::option::Option< i32 > is optional. Good to verify alloc::vec::Vec< i32 > is vector.

Returns a Span covering the complete contents of this syntax tree node, or Span::call_site() if this node is empty.