Function wproc_macro::span_of [−][src]
Returns a Span covering the complete contents of this syntax tree node, or Span::call_site() if this node is empty.
Works only for items for which span is not implemented in module::syn. For other use macro span_of!.